@@ -1,40 +1,40 @@
 #' @name manageCache
-#' 
+#'
 #' @title Manage the size of a cache
-#' 
+#'
 #' @param cacheDir Location of cache directory.
 #' @param extensions Vector of file extensions eligible for removal.
 #' @param maxCacheSize Maximum cache size in megabytes.
 #' @param sortBy Timestamp to sort by when sorting files eligible for removal.
 #'   One of \code{atime|ctime|mtime}.
 #' @param maxFileAge Maximum age in days of files allowed in the cache.
-#'   
+#'
 #' @return Invisibly returns the number of files removed.
-#' 
+#'
 #' @description
 #' If \code{cacheDir} takes up more than \code{maxCacheSize}
 #' megabytes on disk, files will be removed in order of access time by
 #' default. Only files matching \code{extensions} are eligible for removal.
-#' Files can also be removed in order of change time with \code{sortBy='ctime'}  
+#' Files can also be removed in order of change time with \code{sortBy='ctime'}
 #' or modification time with \code{sortBy='mtime'}.
-#' 
+#'
 #' The \code{maxFileAge} parameter can also be used to remove files that haven't
-#' been modified in a certain number of days. Fractional days are allowed. This 
-#' removal happens without regard to the size of the cache and is useful for 
+#' been modified in a certain number of days. Fractional days are allowed. This
+#' removal happens without regard to the size of the cache and is useful for
 #' removing out-of-date data.
-#' 
+#'
 #' It is important to understand precisely what these timestamps
 #' represent:
 #' \itemize{
 #' \item{\code{atime} -- File access time: updated whenever a file is opened.}
 #' \item{\code{ctime} -- File change time: updated whenever a file's metadata
 #' changes e.g. name, permission, ownership.}
-#' \item{\code{mtime} -- file modification time: updated whenever a file's 
+#' \item{\code{mtime} -- file modification time: updated whenever a file's
 #' contents change.}
 #' }
-#' 
+#'
 #' @export
-#' 
+#'
 #' @examples
 #' # Create a cache directory and fill it with 1.6 MB of data
 #' CACHE_DIR <- tempdir()
@@ -45,13 +45,13 @@
 #' for (file in list.files(CACHE_DIR, full.names=TRUE)) {
 #'   print(file.info(file)[,c(1,6)])
 #' }
-#' 
+#'
 #' # Remove files based on access time until we get under 1 MB
 #' manageCache(CACHE_DIR, extensions='csv', maxCacheSize=1, sortBy='atime')
 #' for (file in list.files(CACHE_DIR, full.names=TRUE)) {
 #'   print(file.info(file)[,c(1,6)])
 #' }
-#' 
+#'
 #' # Or remove files based on modification time
 #' manageCache(CACHE_DIR, extensions='csv', maxCacheSize=1, sortBy='mtime')
 #' for (file in list.files(CACHE_DIR, full.names=TRUE)) {
@@ -65,10 +65,10 @@ manageCache <- function(cacheDir,
                         maxFileAge = NULL) {
 
   # Get file info --------------------------------------------------------------
-  
+
   # Convert incoming size from megabytes to bytes
   maxCacheSize <- as.numeric(maxCacheSize) * 1e6
-  
+
   # Get all files appropriate for deletion
   filesList <- list()
   for ( extension in extensions ) {
@@ -79,7 +79,7 @@ manageCache <- function(cacheDir,
                                          full.names=TRUE)
   }
   cacheFiles <- unlist(filesList, use.names=FALSE)
-  
+
   # Create a dataframe with access times and file sizes
   cacheDF <- file.info(cacheFiles)
   cacheDF$file <- rownames(cacheDF)
@@ -89,7 +89,7 @@ manageCache <- function(cacheDir,
   if ( is.null(maxFileAge) ) {
     ageRemovalCount <- 0
   } else {
-    expiration <- lubridate::now() - lubridate::ddays(maxFileAge)
+    expiration <- lubridate::now(tzone = "UTC") - lubridate::ddays(maxFileAge)
     removalDF <- dplyr::filter(cacheDF, cacheDF$mtime < expiration)
     ageRemovalCount <- nrow(removalDF)
     if ( ageRemovalCount > 0 ) {
@@ -98,21 +98,17 @@ manageCache <- function(cacheDir,
   }
 
   # Remove excess files --------------------------------------------------------
-  
+
   # Use dplyr to order by value specified by sortBy
-  if ( sortBy == 'atime' ) {
-    sizeByDF <- dplyr::arrange_(cacheDF, "desc(atime)")
-  } else if ( sortBy == 'ctime') {
-    sizeByDF <- dplyr::arrange_(cacheDF, "desc(ctime)")
-  } else if ( sortBy == 'mtime') {
-    sizeByDF <- dplyr::arrange_(cacheDF, "desc(mtime)")
-  } else {
+  if ( !sortBy %in% c("atime", "ctime", "mtime") ) {
     stop("Invalid value for parameter 'sortBy'")
+  } else {
+    sizeByDF <- dplyr::arrange(cacheDF, dplyr::desc(.data[[sortBy]]))
   }
-  
+
   # Compute a running total
   sizeByDF$cumulativeSize <- cumsum(sizeByDF$size)
-  
+
   # Remove all files associated with cumulativeSize > maxCacheSize
   removalMask <- sizeByDF$cumulativeSize > maxCacheSize
   removalFiles <- sizeByDF$file[removalMask]
@@ -120,11 +116,11 @@ manageCache <- function(cacheDir,
   if ( sizeRemovalCount > 0 ) {
     file.remove(removalFiles)
   }
-  
+
   # Return ---------------------------------------------------------------------
-  
+
   removalCount <- ageRemovalCount + sizeRemovalCount
-  
+
   return(invisible(removalCount))
-  
+
 }
